define(["require", "exports", "babylonjs", "matter-js", "./Box", "./Sphere"], function (require, exports, BABYLON, Matter, Box_1, Sphere_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var Scene3D = /** @class */ (function () {
        function Scene3D(canvasName) {
            var _this = this;
            this.RATIO = 100;
            this._matterEngine = Matter.Engine.create();
            this._matterEngine.world.gravity.y = -1;
            var canvas = document.getElementById(canvasName);
            this._engine = new BABYLON.Engine(canvas, true);
            this._scene = this.createScene(canvas);
            window.onresize = function () { return _this._engine.resize(); };
            this.createWallsAndFloor();
            this.createPhysicsSimulation();
            this.doRender();
        }
        Scene3D.prototype.createScene = function (canvas) {
            var scene = new BABYLON.Scene(this._engine);
            var camera = new BABYLON.ArcRotateCamera("arcCamera", BABYLON.Tools.ToRadians(-90), BABYLON.Tools.ToRadians(90), 15, new BABYLON.Vector3(0, 3, 0), scene);
            camera.attachControl(canvas, true);
            camera.wheelPrecision = 100;
            var light = new BABYLON.HemisphericLight("hemisphericLight", new BABYLON.Vector3(0.1, 1, -0.3), scene);
            this._box1 = new Box_1.default(2, 4, 1, 1, 1, false, this.RATIO, this._matterEngine, scene);
            this._box2 = new Box_1.default(-1.5, 4, 1, 1, 1, false, this.RATIO, this._matterEngine, scene);
            var staticSphere = new Sphere_1.default(2, 0.5, 1, true, this.RATIO, this._matterEngine, scene);
            var staticBox = new Box_1.default(-2, 0.5, 1, 1, 1, true, this.RATIO, this._matterEngine, scene);
            var ground = new Box_1.default(0, -0.5, 10, 1, 2, true, this.RATIO, this._matterEngine, scene);
            var skybox = BABYLON.MeshBuilder.CreateBox("skybox", { size: 1000 }, scene);
            skybox.infiniteDistance = true;
            var skyboxMaterial = new BABYLON.StandardMaterial("skyboxMat", scene);
            skyboxMaterial.backFaceCulling = false;
            var files = [
                "images/skybox_px.jpg",
                "images/skybox_py.jpg",
                "images/skybox_pz.jpg",
                "images/skybox_nx.jpg",
                "images/skybox_ny.jpg",
                "images/skybox_nz.jpg",
            ];
            skyboxMaterial.reflectionTexture = BABYLON.CubeTexture.CreateFromImages(files, scene);
            skyboxMaterial.reflectionTexture.coordinatesMode = BABYLON.Texture.SKYBOX_MODE;
            skyboxMaterial.diffuseColor = new BABYLON.Color3(0, 0, 0);
            skyboxMaterial.specularColor = new BABYLON.Color3(0, 0, 0);
            skybox.material = skyboxMaterial;
            return scene;
        };
        Scene3D.prototype.createWallsAndFloor = function () {
            var staticSphereBody = Matter.Bodies.circle(200, 50, 50, { isStatic: true });
            var staticBoxBody = Matter.Bodies.rectangle(-200, 50, 100, 100, { isStatic: true });
            var ground = Matter.Bodies.rectangle(0, -50, 500, 100, { isStatic: true });
            Matter.World.add(this._matterEngine.world, [ground, staticSphereBody, staticBoxBody]);
        };
        Scene3D.prototype.doRender = function () {
            var _this = this;
            this._engine.runRenderLoop(function () { return _this._scene.render(); });
        };
        Scene3D.prototype.createPhysicsSimulation = function () {
            var _this = this;
            setInterval(function () {
                _this.updatePhysics();
            }, 15);
        };
        Scene3D.prototype.updatePhysics = function () {
            Matter.Engine.update(this._matterEngine);
            this._box1.update();
            this._box2.update();
        };
        return Scene3D;
    }());
    exports.default = Scene3D;
});
//# sourceMappingURL=Scene3D.js.map